optmanage
=========

.. automodule:: optmanage

optmanage.__all__
-----------------

The following members were explicitly reexported using ``__all__``:

    - :py:class:`optmanage.option.Option`
    - :py:class:`optmanage.manager.OptionManager`
